@@ -1,4 +1,5 @@
 package CHI::CacheObject;
+use CHI::Constants qw(CHI_Max_Time);
 use strict;
 use warnings;
 
@@ -11,7 +12,7 @@ use constant f_expires_at       => 5;
 use constant f_is_serialized    => 6;
 use constant f_cache_version    => 7;
 use constant f_value            => 8;
-use constant f_size             => 9;
+use constant f_packed_data      => 9;
 
 my $Metadata_Format = "LLLCC";
 my $Metadata_Length = 14;
@@ -25,13 +26,17 @@ sub early_expires_at { $_[0]->[f_early_expires_at] }
 sub expires_at       { $_[0]->[f_expires_at] }
 sub serializer       { $_[0]->[f_serializer] }
 sub _is_serialized   { $_[0]->[f_is_serialized] }
-sub size             { $_[0]->[f_size] }
+sub size             { length( $_[0]->[f_raw_value] ) + $Metadata_Length }
 
-sub set_key              { $_[0]->[f_key]              = $_[1] }
-sub set_created_at       { $_[0]->[f_created_at]       = $_[1] }
-sub set_early_expires_at { $_[0]->[f_early_expires_at] = $_[1] }
-sub set_expires_at       { $_[0]->[f_expires_at]       = $_[1] }
-sub set_serializer       { $_[0]->[f_serializer]       = $_[1] }
+sub set_early_expires_at {
+    $_[0]->[f_early_expires_at] = $_[1];
+    undef $_[0]->[f_packed_data];
+}
+
+sub set_expires_at {
+    $_[0]->[f_expires_at] = $_[1];
+    undef $_[0]->[f_packed_data];
+}
 
 ## no critic (ProhibitManyArgs)
 sub new {
@@ -69,26 +74,30 @@ sub unpack_from_data {
         $serializer, unpack( $Metadata_Format, $metadata )
       ],
       $class;
-    $obj->[f_size] = length($data);
+    $obj->[f_packed_data] = $data;
     return $obj;
 }
 
 sub pack_to_data {
     my ($self) = @_;
 
-    my $data =
-      pack( $Metadata_Format, ( @{$self} )[ f_created_at .. f_cache_version ] )
-      . $self->[f_raw_value];
-    $self->[f_size] = length($data);
-    return $data;
+    if ( !defined( $self->[f_packed_data] ) ) {
+        my $data = pack( $Metadata_Format,
+            ( @{$self} )[ f_created_at .. f_cache_version ] )
+          . $self->[f_raw_value];
+        $self->[f_packed_data] = $data;
+    }
+    return $self->[f_packed_data];
 }
 
 sub is_expired {
     my ($self) = @_;
 
-    my $time             = $CHI::Driver::Test_Time || time();
+    my $expires_at = $self->[f_expires_at];
+    return undef if $expires_at == CHI_Max_Time;
+
+    my $time = $CHI::Driver::Test_Time || time();
     my $early_expires_at = $self->[f_early_expires_at];
-    my $expires_at       = $self->[f_expires_at];
 
     return $time >= $early_expires_at
       && (
